Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4)

Unified Diff: third_party/closure_compiler/interfaces/system_display_interface.js

Issue 2656433004: - Plumbs through native touch calibration from MD settings to display manager via the system dis… (Closed)
Patch Set: Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/closure_compiler/externs/system_display.js ('k') | tools/metrics/histograms/histograms.xml » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/closure_compiler/interfaces/system_display_interface.js
diff --git a/third_party/closure_compiler/interfaces/system_display_interface.js b/third_party/closure_compiler/interfaces/system_display_interface.js
index 683e7d829eec528be177cc5e45c76aa67ce5b309..84542264215dded21b6d17d1000c8d468621679d 100644
--- a/third_party/closure_compiler/interfaces/system_display_interface.js
+++ b/third_party/closure_compiler/interfaces/system_display_interface.js
@@ -96,35 +96,45 @@ SystemDisplay.prototype = {
overscanCalibrationComplete: assertNotReached,
/**
* Starts touch calibration for a display. This will show an overlay on the
* screen and initialize the UX for touch calibration. If touch calibration
* for display |id| is in progress this will reset calibration.
* @param {string} id The display's unique identifier.
- * @see https://developer.chrome.com/extensions/system.display#method-touchCalibrationStart
+ * @see https://developer.chrome.com/extensions/system.display#method-showNativeTouchCalibration
*/
- touchCalibrationStart: assertNotReached,
+ showNativeTouchCalibration: assertNotReached,
/**
- * Sets the touch calibration pairs for a display. These |pairs| would be used
- * to calibrate the touch screen for display |id|. If touch calibration for
- * display |id| is in progress this will do nothing.
+ * Starts custom touch calibration for a display. This should be called when
+ * using a custom UX for collecting calibration data. If another touch
+ * calibration is already in progress this will throw an error.
* @param {string} id The display's unique identifier.
+ * @see https://developer.chrome.com/extensions/system.display#method-startCustomTouchCalibration
+ */
+ startCustomTouchCalibration: assertNotReached,
+
+ /**
+ * Sets the touch calibration pairs for a display. These |pairs| would be used
+ * to calibrate the touch screen for display with |id| called in
+ * startCustomTouchCalibration(). Always call |startCustomTouchCalibration|
+ * before calling this method. If another touch calibration is already in
+ * progress this will throw an error.
* @param {!chrome.system.display.TouchCalibrationPairQuad} pairs The pairs of
* point used to calibrate the display.
* @param {!chrome.system.display.Bounds} bounds Bounds of the display when
- * the touch calibration was performed. |bounds.left| and |bounds.top|
- * values are no-op.
- * @see https://developer.chrome.com/extensions/system.display#method-touchCalibrationSet
+ * the touch calibration was performed. |bounds.left| and |bounds.top|
+ * values are ignored.
+ * @see https://developer.chrome.com/extensions/system.display#method-completeCustomTouchCalibration
*/
- touchCalibrationSet: assertNotReached,
+ completeCustomTouchCalibration: assertNotReached,
/**
* Resets the touch calibration for the display and removes the saved
* calibration data.
* @param {string} id The display's unique identifier.
- * @see https://developer.chrome.com/extensions/system.display#method-touchCalibrationReset
+ * @see https://developer.chrome.com/extensions/system.display#method-clearTouchCalibration
*/
- touchCalibrationReset: assertNotReached,
+ clearTouchCalibration: assertNotReached,
};
/**
« no previous file with comments | « third_party/closure_compiler/externs/system_display.js ('k') | tools/metrics/histograms/histograms.xml » ('j') | no next file with comments »
@@ -96,35 +96,45 @@ SystemDisplay.prototype = {
overscanCalibrationComplete: assertNotReached,
/**
- * Starts touch calibration for a display. This will show an overlay on the
- * screen and initialize the UX for touch calibration. If touch calibration
- * for display |id| is in progress this will reset calibration.
+ * Starts native touch calibration for a display. This will show an overlay on
+ * the screen and initialize the UX for touch calibration. If another native
+ * touch calibration is already in progress this will throw an error.
* @param {string} id The display's unique identifier.

Powered by Google App Engine
This is Rietveld 408576698